# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: powerpay_protos/telemetry/telemetry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from powerpay_protos.telemetry import measurement_pb2 as powerpay__protos_dot_telemetry_dot_measurement__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)powerpay_protos/telemetry/telemetry.proto\x12\x12powerpay.telemetry\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+powerpay_protos/telemetry/measurement.proto\"\x9e\x01\n\tTelemetry\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32\x1a.powerpay.telemetry.Device\x12\x36\n\x0bmeasurement\x18\x03 \x03(\x0b\x32!.powerpay.measurement.Measurement\"\xa7\x02\n\x06\x44\x65vice\x12\x11\n\tnative_id\x18\x01 \x01(\t\x12\x44\n\x10integration_type\x18\x02 \x01(\x0e\x32*.powerpay.telemetry.Device.IntegrationType\x12\x19\n\x0coutlet_index\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x10integration_name\x18\x04 \x01(\t\x12\x1c\n\x0flora_gateway_id\x18\x05 \x01(\tH\x01\x88\x01\x01\"L\n\x0fIntegrationType\x12\x1e\n\x1aINTEGRATION_TYPE_UNDEFINED\x10\x00\x12\x0e\n\nCHIRPSTACK\x10\x01\x12\t\n\x05\x45\x41SEE\x10\x02\x42\x0f\n\r_outlet_indexB\x12\n\x10_lora_gateway_idb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.telemetry.telemetry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TELEMETRY']._serialized_start=144
  _globals['_TELEMETRY']._serialized_end=302
  _globals['_DEVICE']._serialized_start=305
  _globals['_DEVICE']._serialized_end=600
  _globals['_DEVICE_INTEGRATIONTYPE']._serialized_start=487
  _globals['_DEVICE_INTEGRATIONTYPE']._serialized_end=563
# @@protoc_insertion_point(module_scope)
